/*
 * GraphEventHandler.cpp
 *
 *  Created on: 02.04.2013
 *      Author: cls
 */

#include <networkit/dynamics/GraphEventHandler.hpp>

namespace NetworKit {

} /* namespace NetworKit */
